Scroller example - Semantic UI

# Scroller example Semantic UI

This example shows DataTables and the Scroller extension being used with Semantic UI providing the styling. The DataTables / Semantic UI integration provides seamless integration for DataTables to be used in a Semantic UI page.

ID | First name | Last name | ZIP / Post code | Country
--- | --- | --- | --- | ---

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { $('#example').DataTable( { ajax: "../data/2500.txt", deferRender: true, scrollY: 200, scrollCollapse: true, scroller: true } ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- //code.jquery.com/jquery-1.12.3.min.js
- ../../../../media/js/jquery.dataTables.js
- ../../../../media/js/dataTables.semanticui.js
- ../../js/dataTables.scroller.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- //cdnjs.cloudflare.com/ajax/libs/semantic-ui/2.1.8/semantic.min.css
- ../../../../media/css/dataTables.semanticui.css
- ../../css/scroller.semanticui.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.